InnerCompletionHandler class
- Inheritance
-
- Object
- CompletionHandler
- InnerCompletionHandler
Constructors
- InnerCompletionHandler(DsWebViewController controller, String? cb)
Properties
- cb → String?
-
final
- controller → DsWebViewController
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
complete(
[dynamic retValue]) → void -
override
-
completeProcess(
dynamic retValue, bool complete) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setProgressData(
dynamic value) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited