InnerJavaScriptNamespaceInterface class
- Inheritance
-
- Object
- JavaScriptNamespaceInterface
- InnerJavaScriptNamespaceInterface
Constructors
- InnerJavaScriptNamespaceInterface(DsWebViewController controller)
Properties
- controller → DsWebViewController
-
final
-
functionMap
↔ Map<
String, Function> -
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- namespace ↔ String?
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
closePage(
dynamic args) → void -
disableJavascriptDialogBlock(
dynamic args) → void -
dsinit(
dynamic args) → void -
hasNativeMethod(
dynamic args) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
) → void -
override
-
registerFunction(
Function function, {String? functionName}) → bool -
inherited
-
returnValue(
dynamic args) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited